@@ -2,6 +2,8 @@
 pub mod controller;
 pub mod service;
 pub mod types;
+#[cfg(feature = "pubsub")]
+pub mod pubsub;
 
 pub const EAPI_VERSION: u16 = 1;
 
